media library

UIImage, scopes, preview frames, and SVG icon widgets.

Classes

UIImage
Unified image widget for assets, network URLs, SVG, and base64 sources.
UIImageNetworkParams
Parameters passed to UIImageScope.networkImageBuilder.
UIImagePreviewFrame
Fixed 16:9 frame for image previews.
UIImageScope
Supplies optional image and SVG builders for UIImage and related widgets.
UIImageSvgParams
Parameters passed to UIImageScope.svgBuilder.
UISocialAuthAssets
Default SVG asset paths for UISocialAuthProvider icons shipped with this package.
UISocialAuthIcon
Renders a provider brand icon from a package or host-app SVG asset.
UISvgAssetIcon
Renders an SVG asset using a lightweight custom painter.
UISvgImage
Renders simple SVG sources using a lightweight custom painter.
UISvgParsedData
Parsed SVG path data with its coordinate bounds.

Functions

imagePreviewImage(String imagePath, {required String fallbackTitle, BoxFit fit = BoxFit.contain, int? cacheWidth, int? cacheHeight, Color gradientStart = const Color(0xFFE8EDF5), Color gradientEnd = const Color(0xFFDCE4F0), Color accentColor = const Color(0xFF4F5D9A), Color iconColor = const Color(0xFF94A3B8)}) Widget
imagePreviewPlaceholder(BuildContext context, String projectName, {Color gradientStart = const Color(0xFFE8EDF5), Color gradientEnd = const Color(0xFFDCE4F0), Color accentColor = const Color(0xFF4F5D9A), Color iconColor = const Color(0xFF94A3B8)}) Widget
parseSvgDocument(String svg) UISvgParsedData?
Extracts path data and view box from a simple SVG document.
parseSvgPathData(String pathData) Path
Parses an SVG path data string (d attribute) into a Flutter Path.

Typedefs

UIImageNetworkBuilder = Widget Function(BuildContext context, UIImageNetworkParams params)
Builder for network images supplied through UIImageScope.
UIImageSvgBuilder = Widget Function(BuildContext context, UIImageSvgParams params)
Builder for SVG images supplied through UIImageScope.