isInPast property
bool
get
isInPast
Returns true when this date is before the current moment.
Implementation
bool get isInPast => isBefore(DateTime.now());
Returns true when this date is before the current moment.
bool get isInPast => isBefore(DateTime.now());