isTomorrow method
Returns true when this date falls on tomorrow (local calendar day).
Implementation
bool isTomorrow() {
final tomorrow = DateTime.now().add(const Duration(days: 1));
return DateTimeUtil.isSameDay(this, tomorrow);
}
Returns true when this date falls on tomorrow (local calendar day).
bool isTomorrow() {
final tomorrow = DateTime.now().add(const Duration(days: 1));
return DateTimeUtil.isSameDay(this, tomorrow);
}