UIAlertPanel class
Inline alert panel with icon, title, description, and optional actions.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- UIAlertPanel
Constructors
- UIAlertPanel({String? title, String? description, required UIAlertPanelStyle style, Key? key, Widget? icon, Widget? titleChild, Widget? descriptionChild, VoidCallback? onClose, Widget? primaryAction, Widget? secondaryAction, bool showCloseButton = true, Widget? customContent, UIDialogProps dialog = const UIDialogProps()})
-
const
Properties
- customContent → Widget?
-
final
- description → String?
-
final
- descriptionChild → Widget?
-
final
- dialog → UIDialogProps
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onClose → VoidCallback?
-
final
- primaryAction → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryAction → Widget?
-
final
- showCloseButton → bool
-
final
- style → UIAlertPanelStyle
-
final
- title → String?
-
final
- titleChild → Widget?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
copyWith(
{Key? key, String? title, String? description, UIAlertPanelStyle? style, Widget? icon, Widget? titleChild, Widget? descriptionChild, Widget? primaryAction, Widget? secondaryAction, VoidCallback? onClose, bool? showCloseButton, Widget? customContent, UIDialogProps? dialog}) → UIAlertPanel -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited