UIAlertTheme class

Inline alert styling tokens.

Inheritance

Constructors

UIAlertTheme({double borderRadius = 12, EdgeInsetsGeometry padding = const EdgeInsets.all(16)})
const

Properties

borderRadius double
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsetsGeometry
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Object
The extension's type.
no setterinherited

Methods

copyWith({double? borderRadius, EdgeInsetsGeometry? padding}) UIAlertTheme
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<UIAlertTheme>? other, double t) UIAlertTheme
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

standard → const UIAlertTheme