UIAnimatedFlipCardStyle class

Visual configuration for UIAnimatedFlipCard.

Constructors

UIAnimatedFlipCardStyle({double? width, double? height, BorderRadius? borderRadius, List<BoxShadow>? shadows, Color? frontColor, Color? backColor, Border? border, Duration flipDuration = const Duration(milliseconds: 400), Curve flipCurve = Curves.easeInOut, EdgeInsets? padding, BoxDecoration? frontDecoration, BoxDecoration? backDecoration, UIFlipDirection direction = UIFlipDirection.horizontal, bool fill = false})
const

Properties

backColor → Color?
final
backDecoration → BoxDecoration?
final
border → Border?
final
borderRadius → BorderRadius?
final
direction → UIFlipDirection
final
fill → bool
final
flipCurve → Curve
final
flipDuration → Duration
final
frontColor → Color?
final
frontDecoration → BoxDecoration?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
padding → EdgeInsets?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadows → List<BoxShadow>?
final
width → double?
final

Methods

copyWith({double? width, double? height, BorderRadius? borderRadius, List<BoxShadow>? shadows, Color? frontColor, Color? backColor, Border? border, Duration? flipDuration, Curve? flipCurve, EdgeInsets? padding, BoxDecoration? frontDecoration, BoxDecoration? backDecoration, UIFlipDirection? direction, bool? fill}) → UIAnimatedFlipCardStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited