UIAppBarProps class
Forwarded AppBar parameters for kit app bar wrappers.
- Annotations
Constructors
-
UIAppBarProps({List<
Widget> ? actions, bool? automaticallyImplyLeading, PreferredSizeWidget? bottom, bool? centerTitle, double? elevation, double? scrolledUnderElevation, Color? shadowColor, Color? surfaceTintColor, Color? backgroundColor, Color? foregroundColor, IconThemeData? iconTheme, IconThemeData? actionsIconTheme, bool? primary, double? titleSpacing, double? toolbarOpacity, double? bottomOpacity, double? leadingWidth, double? toolbarHeight, Widget? leading, Widget? flexibleSpace}) -
const
Properties
-
actions
→ List<
Widget> ? -
final
- actionsIconTheme → IconThemeData?
-
final
- automaticallyImplyLeading → bool?
-
final
- backgroundColor → Color?
-
final
- bottom → PreferredSizeWidget?
-
final
- bottomOpacity → double?
-
final
- centerTitle → bool?
-
final
- elevation → double?
-
final
- flexibleSpace → Widget?
-
final
- foregroundColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconTheme → IconThemeData?
-
final
- leading → Widget?
-
final
- leadingWidth → double?
-
final
- primary → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrolledUnderElevation → double?
-
final
- shadowColor → Color?
-
final
- surfaceTintColor → Color?
-
final
- titleSpacing → double?
-
final
- toolbarHeight → double?
-
final
- toolbarOpacity → double?
-
final
Methods
-
build(
{Key? key, required Widget title, bool? defaultCenterTitle, double? defaultElevation, Color? defaultBackgroundColor, Color? defaultForegroundColor}) → AppBar -
copyWith(
{List< Widget> ? actions, bool? automaticallyImplyLeading, PreferredSizeWidget? bottom, bool? centerTitle, double? elevation, double? scrolledUnderElevation, Color? shadowColor, Color? surfaceTintColor, Color? backgroundColor, Color? foregroundColor, IconThemeData? iconTheme, IconThemeData? actionsIconTheme, bool? primary, double? titleSpacing, double? toolbarOpacity, double? bottomOpacity, double? leadingWidth, double? toolbarHeight, Widget? leading, Widget? flexibleSpace}) → UIAppBarProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited