UICarouselControls class
Prev/next buttons and page indicators for carousels.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- UICarouselControls
Constructors
-
UICarouselControls({Key? key, required int pageCount, required int currentPage, bool loop = false, required VoidCallback onPrevious, required VoidCallback onNext, required ValueChanged<
int> onPageSelected, UICarouselControlsColors? colors = const UICarouselControlsColors()}) -
const
Properties
- colors → UICarouselControlsColors?
-
final
- currentPage → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loop → bool
-
final
- onNext → VoidCallback
-
final
-
onPageSelected
→ ValueChanged<
int> -
final
- onPrevious → VoidCallback
-
final
- pageCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
copyWith(
{Key? key, int? pageCount, int? currentPage, bool? loop, VoidCallback? onPrevious, VoidCallback? onNext, ValueChanged< int> ? onPageSelected, UICarouselControlsColors? colors}) → UICarouselControls -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited