UICarouselControlsColors class
Color tokens for UICarouselControls navigation and indicators.
- Annotations
Constructors
- UICarouselControlsColors({Color indicatorActive = const Color(0xFF6366F1), Color indicatorInactive = const Color(0xFFCBD5E1), Color accent = const Color(0xFF4F46E5)})
-
const
Properties
- accent → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indicatorActive → Color
-
final
- indicatorInactive → Color
-
final
-
final
-
final
-
final
-
final
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Color? indicatorActive, Color? indicatorInactive, Color? accent}) → UICarouselControlsColors -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited