UICouponClipper class

Clips a widget to a split-panel coupon shape with curved tear lines.

Use with ClipPath or UICouponCard. For circular edge notches, see UITicketClipper.

Inheritance
Available extensions

Constructors

UICouponClipper({double borderRadius = 8, double curveRadius = 20, double curvePosition = 100, Axis curveAxis = Axis.horizontal, TextDirection direction = TextDirection.ltr, bool clockwise = false})
const

Properties

borderRadius double
final
clockwise bool
final
curveAxis Axis
final
curvePosition double
final
curveRadius double
final
direction TextDirection
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to reclip.
inherited
builder({required TransitionBuilder builder, Widget? child}) Widget

Available on Listenable, provided by the ListenableExtension extension

Rebuilds builder whenever this listenable notifies listeners.
getApproximateClipRect(Size size) Rect
Returns an approximation of the clip returned by getClip, as an axis-aligned Rect. This is used by the semantics layer to determine whether widgets should be excluded.
inherited
getClip(Size size) Path
Returns a description of the clip given that the render object being clipped is of the given size.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to reclip.
inherited
shouldReclip(covariant UICouponClipper oldClipper) bool
Called whenever a new instance of the custom clipper delegate class is provided to the clip object, or any time that a new clip object is created with a new instance of the custom clipper delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited