UICustomMessageDialog class

Message dialog with title, body, and positive/negative action buttons.

Inheritance

Constructors

UICustomMessageDialog({Key? key, String? msg, Widget? msgWidget, String? title, Widget? titleWidget, String? positiveBtn, VoidCallback? onPositiveClick, String? negativeBtn, VoidCallback? onNegativeClick, Color? negativeBtnTextColor, Color? positiveBtnTextColor, Color? positiveBtnBgColor, int? titleFontSize, FontWeight? titleFontWeight, int? msgFontSize, FontWeight? msgFontWeight, int? positiveBtnFontSize, FontWeight? positiveBtnFontWeight, int? negativeBtnFontSize, FontWeight? negativeBtnFontWeight, Color? dividerColor, Color? dialogTextColor, bool useSimpleActions = false, Color? negativeButtonColor})
const
UICustomMessageDialog.simple({Key? key, required String? msg, String? title, required String? positiveBtn, VoidCallback? onPositiveClick, String? negativeBtn, VoidCallback? onNegativeClick, Color? negativeButtonColor})
Simple alert-style dialog (legacy alias: UIMessageDialog).
const

Properties

dialogTextColor Color?
final
dividerColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
msg String?
final
msgFontSize int?
final
msgFontWeight FontWeight?
final
msgWidget Widget?
final
negativeBtn String?
final
negativeBtnFontSize int?
final
negativeBtnFontWeight FontWeight?
final
negativeBtnTextColor Color?
final
negativeButtonColor Color?
final
onNegativeClick VoidCallback?
final
onPositiveClick VoidCallback?
final
positiveBtn String?
final
positiveBtnBgColor Color?
final
positiveBtnFontSize int?
final
positiveBtnFontWeight FontWeight?
final
positiveBtnTextColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
titleFontSize int?
final
titleFontWeight FontWeight?
final
titleWidget Widget?
final
useSimpleActions bool
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
copyWith({Key? key, String? title, Widget? titleWidget, String? msg, Widget? msgWidget, String? positiveBtn, String? negativeBtn, VoidCallback? onPositiveClick, VoidCallback? onNegativeClick, Color? negativeBtnTextColor, Color? positiveBtnTextColor, Color? positiveBtnBgColor, int? titleFontSize, FontWeight? titleFontWeight, int? msgFontSize, FontWeight? msgFontWeight, int? positiveBtnFontSize, FontWeight? positiveBtnFontWeight, int? negativeBtnFontSize, FontWeight? negativeBtnFontWeight, Color? dividerColor, Color? dialogTextColor, bool? useSimpleActions, Color? negativeButtonColor}) UICustomMessageDialog
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited