UICustomOutlinedButton class

Outlined button with custom border, radius, and label styling.

Inheritance

Constructors

UICustomOutlinedButton({Key? key, required VoidCallback? onPressed, IconData? icon, Widget? iconWidget, IconData? labelIcon, Widget? labelIconWidget, String? label, Widget? labelChild, Widget? child, double iconSize = 18.0, double? gap, Color? foregroundColor, Color? backgroundColor, Color? borderColor, EdgeInsetsGeometry? padding = const EdgeInsets.symmetric(horizontal: 4.0, vertical: 8.0), UIMaterialButtonProps material = const UIMaterialButtonProps()})
const

Properties

backgroundColor Color?
final
borderColor Color?
final
child Widget?
final
foregroundColor Color?
final
gap double?
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
final
iconSize double
final
iconWidget Widget?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
final
labelChild Widget?
final
labelIcon IconData?
final
labelIconWidget Widget?
final
material UIMaterialButtonProps
final
onPressed VoidCallback?
final
padding EdgeInsetsGeometry?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
copyWith({Key? key, VoidCallback? onPressed, IconData? icon, Widget? iconWidget, IconData? labelIcon, Widget? labelIconWidget, String? label, Widget? labelChild, Widget? child, double? iconSize, double? gap, Color? foregroundColor, Color? backgroundColor, Color? borderColor, EdgeInsetsGeometry? padding, UIMaterialButtonProps? material}) UICustomOutlinedButton
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited