UIDialogProps class
Forwarded Dialog parameters for kit dialog wrappers.
- Annotations
Constructors
- UIDialogProps({EdgeInsets? insetPadding, Clip? clipBehavior, ShapeBorder? shape, AlignmentGeometry? alignment, Color? backgroundColor, double? elevation, Color? shadowColor, Color? surfaceTintColor})
-
const
Properties
- alignment → AlignmentGeometry?
-
final
- backgroundColor → Color?
-
final
- clipBehavior → Clip?
-
final
- elevation → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- insetPadding → EdgeInsets?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowColor → Color?
-
final
- shape → ShapeBorder?
-
final
- surfaceTintColor → Color?
-
final
Methods
-
build(
{Key? key, required Widget child, EdgeInsets? defaultInsetPadding, ShapeBorder? defaultShape, Color? defaultBackgroundColor}) → Dialog -
copyWith(
{EdgeInsets? insetPadding, Clip? clipBehavior, ShapeBorder? shape, AlignmentGeometry? alignment, Color? backgroundColor, double? elevation, Color? shadowColor, Color? surfaceTintColor}) → UIDialogProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited