UIDropdown class

A styled dropdown field with optional title and required marker.

Inheritance

Constructors

UIDropdown({Key? key, String? selectedValue, ValueChanged<String>? onChanged, List<String>? items, String? title, required Color titleColor, required Color requiredMarkColor, required Color backgroundColor, required Color borderColor, required Color textColor, String? placeholder, String requiredMarker = ' *', bool showRequiredMarker = true})
const
UIDropdown.fromTheme(BuildContext context, {Key? key, ValueChanged<String>? onChanged, List<String>? items, String? title, String? selectedValue, String? placeholder, Color? titleColor, Color? requiredMarkColor, Color? backgroundColor, Color? borderColor, Color? textColor, String requiredMarker = ' *', bool showRequiredMarker = true})
Creates a UIDropdown with colors derived from Theme.of(context).
factory

Properties

backgroundColor → Color
final
borderColor → Color
final
hashCode → int
The hash code for this object.
no setterinherited
items → List<String>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged → ValueChanged<String>?
final
placeholder → String?
final
requiredMarkColor → Color
final
requiredMarker → String
Text appended after the title to mark a required field.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedValue → String?
final
showRequiredMarker → bool
Whether to display the requiredMarker after the title.
final
textColor → Color
final
title → String?
final
titleColor → Color
final

Methods

copyWith({Key? key, ValueChanged<String>? onChanged, List<String>? items, String? title, String? selectedValue, Color? titleColor, Color? requiredMarkColor, Color? backgroundColor, Color? borderColor, Color? textColor, String? placeholder, String? requiredMarker, bool? showRequiredMarker}) → UIDropdown
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<UIDropdown>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited