UIGlassScaffold class
Scaffold with a gradient background and optional glass chrome wrappers.
Only navigation chrome is frosted — the body is not blurred for performance.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- UIGlassScaffold
Constructors
- UIGlassScaffold({Key? key, PreferredSizeWidget? appBar, Widget? body, Widget? floatingActionButton, FloatingActionButtonLocation? floatingActionButtonLocation, Widget? drawer, Widget? endDrawer, Gradient? backgroundGradient, UIGlassTheme? glassTheme, bool extendBody = false, bool extendBodyBehindAppBar = false, bool? resizeToAvoidBottomInset})
-
const
- UIGlassScaffold.fromTheme(BuildContext context, {Key? key, PreferredSizeWidget? appBar, Widget? body, Widget? floatingActionButton, FloatingActionButtonLocation? floatingActionButtonLocation, Widget? drawer, Widget? endDrawer, Gradient? backgroundGradient, UIGlassTheme? glassTheme, bool extendBody = false, bool extendBodyBehindAppBar = false, bool? resizeToAvoidBottomInset})
-
factory
Properties
- appBar → PreferredSizeWidget?
-
final
- backgroundGradient → Gradient?
-
final
- body → Widget?
-
final
-
final
- drawer → Widget?
-
final
- endDrawer → Widget?
-
final
- extendBody → bool
-
final
- extendBodyBehindAppBar → bool
-
final
- floatingActionButton → Widget?
-
final
- floatingActionButtonLocation → FloatingActionButtonLocation?
-
final
- glassTheme → UIGlassTheme?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- resizeToAvoidBottomInset → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited