UIGlassTheme class
Shared visual tokens for UIGlassSurface and other glass widgets.
Constructors
-
UIGlassTheme({double blur = UIGlassConstants.defaultBlur, double tintOpacity = UIGlassConstants.defaultTintOpacity, double borderRadius = UIGlassConstants.defaultBorderRadius, Color? tintColor, Color? borderColor, double borderWidth = 1, Gradient? gradient, List<
BoxShadow> ? boxShadow, Color? foregroundColor}) -
const
- UIGlassTheme.fromTheme(BuildContext context)
-
factory
Properties
- blur → double
-
final
- borderColor → Color?
-
final
- borderRadius → double
-
final
- borderWidth → double
-
final
-
boxShadow
→ List<
BoxShadow> ? -
final
- foregroundColor → Color?
-
final
- gradient → Gradient?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tintColor → Color?
-
final
- tintOpacity → double
-
final
Methods
-
copyWith(
{double? blur, double? tintOpacity, double? borderRadius, Color? tintColor, Color? borderColor, double? borderWidth, Gradient? gradient, List< BoxShadow> ? boxShadow, Color? foregroundColor}) → UIGlassTheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
UIGlassTheme? a, UIGlassTheme? b, double t) → UIGlassTheme