UIGradientBox class

A container that supports gradient backgrounds and borders.

Inheritance

Constructors

UIGradientBox({Key? key, required Widget child, BorderRadiusGeometry? borderRadius, List<Color>? colors, List<double>? stops, double radius = 1.3, Alignment center = const Alignment(0.0858, 1.6648), EdgeInsets padding = EdgeInsets.zero, EdgeInsetsGeometry margin = EdgeInsets.zero, Gradient? gradient, BoxBorder? border, Gradient? gradientBorder, double? width, double? height, Color? innerColor})
Creates a UIGradientBox.
const

Properties

border → BoxBorder?
Optional standard border.
final
borderRadius → BorderRadiusGeometry?
Optional border radius for the box.
final
center → Alignment
Center for the default radial gradient.
final
child → Widget
The widget to display inside the box.
final
colors → List<Color>?
List of colors for the default gradient.
final
gradient → Gradient?
Optional gradient to use instead of default colors/radial setup.
final
gradientBorder → Gradient?
Optional gradient border.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
Optional fixed height.
final
innerColor → Color?
Optional background color (used if gradient is null).
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsetsGeometry
Outer margin.
final
padding → EdgeInsets
Inner padding.
final
radius → double
Radius for the default radial gradient.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stops → List<double>?
Stops for the default gradient.
final
width → double?
Optional fixed width.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
copyWith({Key? key, Widget? child, BorderRadiusGeometry? borderRadius, List<Color>? colors, List<double>? stops, double? radius, Alignment? center, EdgeInsets? padding, EdgeInsetsGeometry? margin, Gradient? gradient, BoxBorder? border, Gradient? gradientBorder, double? width, double? height, Color? innerColor}) → UIGradientBox
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited