UIScrollableScreen class

Screen wrapper with configurable scroll behavior and safe-area padding.

Inheritance

Constructors

UIScrollableScreen({Key? key, UIScrollableType type = UIScrollableType.singleChild, Widget? child, List<Widget>? slivers, ScrollController? scrollController, ScrollPhysics? physics, bool withRefresh = false, Future<void> onRefresh()?, void onScrollControllerReady(ScrollController controller)?})
const

Properties

child Widget?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onRefresh Future<void> Function()?
final
onScrollControllerReady → void Function(ScrollController controller)?
final
physics ScrollPhysics?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController?
final
slivers List<Widget>?
final
type UIScrollableType
final
withRefresh bool
final

Methods

copyWith({Key? key, UIScrollableType? type, Widget? child, List<Widget>? slivers, ScrollController? scrollController, ScrollPhysics? physics, bool? withRefresh, Future<void> onRefresh()?, void onScrollControllerReady(ScrollController controller)?}) UIScrollableScreen
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<UIScrollableScreen>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited