UISheet class

Styled sheet container used by showUISheet.

Inheritance

Constructors

UISheet({Key? key, required Widget child, UISheetSide side = UISheetSide.bottom, String? title, bool showDragHandle = true, Color? backgroundColor, double? width, double? height, double borderRadius = 16, EdgeInsetsGeometry padding = const EdgeInsets.all(16), bool glass = false, double blur = UIGlassConstants.defaultBlur, double tintOpacity = UIGlassConstants.defaultTintOpacity, UIGlassTheme? glassTheme, Gradient? gradient})
const

Properties

backgroundColor Color?
final
blur double
final
borderRadius double
final
child Widget
final
glass bool
final
glassTheme UIGlassTheme?
final
gradient Gradient?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsetsGeometry
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDragHandle bool
final
side UISheetSide
final
tintOpacity double
final
title String?
final
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited