UIShellDialog class

A customizable dialog shell with title, content, and action buttons.

Inheritance

Constructors

UIShellDialog({Key? key, required UIShellDialogStyle style, String? title, Widget? titleChild, String? content, Widget? contentChild, Widget? contentWidget, Widget? timerCountdown, Widget? imageHeader, Widget? body, List<UIShellDialogAction> actions = const [], bool showCloseButton = true, bool showActionButtons = true, VoidCallback? onClose, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.start, TextStyle? titleStyle, UIDialogProps dialog = const UIDialogProps()})
const

Properties

actions List<UIShellDialogAction>
final
body Widget?
final
content String?
final
contentChild Widget?
final
contentWidget Widget?
final
crossAxisAlignment CrossAxisAlignment
final
dialog UIDialogProps
final
hashCode int
The hash code for this object.
no setterinherited
imageHeader Widget?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onClose VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showActionButtons bool
final
showCloseButton bool
final
style UIShellDialogStyle
final
timerCountdown Widget?
final
title String?
final
titleChild Widget?
final
titleStyle TextStyle?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
copyWith({Key? key, UIShellDialogStyle? style, String? title, Widget? titleChild, TextStyle? titleStyle, String? content, Widget? contentChild, Widget? contentWidget, Widget? timerCountdown, Widget? imageHeader, Widget? body, List<UIShellDialogAction>? actions, bool? showCloseButton, bool? showActionButtons, VoidCallback? onClose, CrossAxisAlignment? crossAxisAlignment, UIDialogProps? dialog}) UIShellDialog
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited