UISideMenu class

Slide-out side menu that overlays or pushes the main child content.

Inheritance

Constructors

UISideMenu({Key? key, required Widget child, Color? background, BorderRadius? radius, required Widget menu, UISideMenuType type = UISideMenuType.slide, double maxMenuWidth = 275.0, bool inverse = false, void onChange(bool isOpened)?})
const

Properties

background Color?
final
child Widget
final
hashCode int
The hash code for this object.
no setterinherited
inverse bool
no setter
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxMenuWidth double
final
final
onChange → void Function(bool isOpened)?
final
radius BorderRadius?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type UISideMenuType
final

Methods

copyWith({Key? key, Widget? child, Color? background, BorderRadius? radius, Widget? menu, UISideMenuType? type, double? maxMenuWidth, bool? inverse, void onChange(bool isOpened)?}) UISideMenu
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() UISideMenuState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext? context) UISideMenuState?