UISnackbar class

A transient overlay snackbar with success and error variants.

Constructors

UISnackbar()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dismiss() → void
show({required BuildContext context, required String message, required UISnackbarStyle style, UISnackbarType type = UISnackbarType.success, Widget? leadingIcon, Widget? closeIcon, Duration duration = const Duration(seconds: 4)}) → void