UIStatSummaryItem class

Represents a single statistic item with a label and a value.

Constructors

UIStatSummaryItem({required String label, required String value})
Creates a UIStatSummaryItem.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
The label describing the statistic.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The value of the statistic.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited