UIAppBar class
Custom app bar with standard, accent, and brand layout variants.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- UIAppBar
- Implemented types
Constructors
-
UIAppBar({Key? key, UIAppBarVariant variant = UIAppBarVariant.standard, Widget? titleWidget, Widget? titleChild, bool? showBackButton, String? backIconPath, String? title, String? logoPath, List<
Widget> ? actionWidgets, VoidCallback? onBackPressed, Color? backgroundColor, Color? iconColor, Color? titleColor, double? fontSize, FontWeight? fontWeight, bool centerTitle = true, double toolbarHeight = 70, Color? accentColor, Widget? leading, List<Widget> actions = const [], VoidCallback? onBack, PreferredSizeWidget? bottom, UIAppBarProps? appBarProps, String? backTooltip}) -
const
-
UIAppBar.accent({Key? key, required String title, required Color accentColor, List<
Widget> actions = const [], VoidCallback? onBack, PreferredSizeWidget? bottom, Widget? titleChild, UIAppBarProps? appBarProps, String? backTooltip}) -
const
-
UIAppBar.brand({Key? key, required String title, Widget? leading, List<
Widget> actions = const [], Widget? titleChild, UIAppBarProps? appBarProps, String? backTooltip}) -
const
Properties
- accentColor → Color?
-
final
-
actions
→ List<
Widget> -
final
-
actionWidgets
→ List<
Widget> ? -
final
- appBarProps → UIAppBarProps?
-
final
- backgroundColor → Color?
-
final
- backIconPath → String?
-
final
- backTooltip → String?
-
Tooltip / semantic label for the back button.
final
- bottom → PreferredSizeWidget?
-
final
- centerTitle → bool
-
final
- fontSize → double?
-
final
- fontWeight → FontWeight?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconColor → Color?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- leading → Widget?
-
final
- logoPath → String?
-
final
- onBack → VoidCallback?
-
final
- onBackPressed → VoidCallback?
-
final
- preferredSize → Size
-
The size this widget would prefer if it were otherwise unconstrained.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showBackButton → bool?
-
final
- title → String?
-
final
- titleChild → Widget?
-
final
- titleColor → Color?
-
final
- titleWidget → Widget?
-
final
- toolbarHeight → double
-
final
- variant → UIAppBarVariant
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
copyWith(
{Key? key, UIAppBarVariant? variant, Widget? titleWidget, Widget? titleChild, bool? showBackButton, String? backIconPath, String? title, String? logoPath, List< Widget> ? actionWidgets, VoidCallback? onBackPressed, Color? backgroundColor, Color? iconColor, Color? titleColor, double? fontSize, FontWeight? fontWeight, bool? centerTitle, double? toolbarHeight, Color? accentColor, Widget? leading, List<Widget> ? actions, VoidCallback? onBack, PreferredSizeWidget? bottom, UIAppBarProps? appBarProps, String? backTooltip}) → UIAppBar -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
contrastOn(
Color background) → Color