UIImage class
Unified image widget for assets, network URLs, SVG, and base64 sources.
- Inheritance
Constructors
- UIImage(String source, {Key? key, bool? isAsset, double? width, double? height, BoxFit fit = BoxFit.contain, Color? color, Alignment alignment = Alignment.center, BorderRadius? borderRadius, Widget? placeholder, Widget? fallback, String urlTransformer(String url)?, String? placeholderPath, Color? placeholderColor, bool showPlaceholder = false, UIImageNetworkBuilder? networkImageBuilder, UIImageSvgBuilder? svgBuilder})
-
const
Properties
- alignment → Alignment
-
final
- borderRadius → BorderRadius?
-
final
- color → Color?
-
final
- fallback → Widget?
-
final
- fit → BoxFit
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- isAsset → bool?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- networkImageBuilder → UIImageNetworkBuilder?
-
Optional per-widget override for UIImageScope.networkImageBuilder.
final
- placeholder → Widget?
-
final
- placeholderColor → Color?
-
final
- placeholderPath → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showPlaceholder → bool
-
final
- source → String
-
final
- svgBuilder → UIImageSvgBuilder?
-
Optional per-widget override for UIImageScope.svgBuilder.
final
- urlTransformer → String Function(String url)?
-
final
- width → double?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
copyWith(
{Key? key, String? source, bool? isAsset, double? width, double? height, BoxFit? fit, Color? color, Alignment? alignment, BorderRadius? borderRadius, Widget? placeholder, Widget? fallback, String urlTransformer(String url)?, String? placeholderPath, Color? placeholderColor, bool? showPlaceholder, UIImageNetworkBuilder? networkImageBuilder, UIImageSvgBuilder? svgBuilder}) → UIImage -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited