UIImageTextButton class
Outlined button with leading image — thin wrapper over Material OutlinedButton.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- UIImageTextButton
Constructors
- UIImageTextButton({Key? key, String? text, Widget? child, VoidCallback? onPressed, double size = 16, FontWeight fontWeight = FontWeight.w600, TextStyle? style, int? maxLines, TextAlign textAlign = TextAlign.center, bool enableButton = true, double cornerRadius = 5, double? width = double.maxFinite, double? height = 61, String? imagePath, Widget? icon, bool hideIcon = false, Color? enableBgColor, Color? disableBgColor, Color? enableTextColor, Color? disableTextColor, Color? enableBorderColor, Color? disableBorderColor, Color? enableIconColor, Color? disableIconColor, UIMaterialButtonProps material = const UIMaterialButtonProps()})
-
const
Properties
- child → Widget?
-
final
- cornerRadius → double
-
final
- disableBgColor → Color?
-
final
- disableBorderColor → Color?
-
final
- disableIconColor → Color?
-
final
- disableTextColor → Color?
-
final
- enableBgColor → Color?
-
final
- enableBorderColor → Color?
-
final
- enableButton → bool
-
final
- enableIconColor → Color?
-
final
- enableTextColor → Color?
-
final
- fontWeight → FontWeight
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- hideIcon → bool
-
final
- icon → Widget?
-
final
- imagePath → String?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- material → UIMaterialButtonProps
-
final
- maxLines → int?
-
final
- onPressed → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
final
- style → TextStyle?
-
final
- text → String?
-
final
- textAlign → TextAlign
-
final
- width → double?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
copyWith(
{Key? key, String? text, Widget? child, VoidCallback? onPressed, double? size, FontWeight? fontWeight, TextStyle? style, int? maxLines, TextAlign? textAlign, bool? enableButton, double? cornerRadius, double? width, double? height, String? imagePath, Widget? icon, bool? hideIcon, Color? enableTextColor, Color? disableTextColor, Color? enableBgColor, Color? disableBgColor, Color? enableBorderColor, Color? disableBorderColor, Color? enableIconColor, Color? disableIconColor, UIMaterialButtonProps? material}) → UIImageTextButton -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited