UIOverlayDropdown class
Overlay dropdown field that opens a positioned selection menu.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- UIOverlayDropdown
Constructors
-
UIOverlayDropdown({required List<
UIOverlayDropdownItem> items, required UIOverlayDropdownStyle style, Key? key, String? value, String? placeholder, ValueChanged<String?> ? onChanged, String displayLabelBuilder(UIOverlayDropdownItem selectedItem, String? value)?, Widget? trailingIcon, bool autoChange = false, void onOverlayInsert(OverlayEntry entry)?, VoidCallback? onOverlayRemove}) -
const
Properties
- autoChange → bool
-
final
- displayLabelBuilder → String Function(UIOverlayDropdownItem selectedItem, String? value)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
UIOverlayDropdownItem> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onChanged
→ ValueChanged<
String?> ? -
final
- onOverlayInsert → void Function(OverlayEntry entry)?
-
final
- onOverlayRemove → VoidCallback?
-
final
- placeholder → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → UIOverlayDropdownStyle
-
final
- trailingIcon → Widget?
-
final
- value → String?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< UIOverlayDropdown> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited