UIRatingBarIndicator class
Read-only rating display that supports fractional values.
Use UIRatingBarIndicator.builder when each item should be built individually.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- UIRatingBarIndicator
Constructors
- UIRatingBarIndicator({Key? key, required double rating, UIRatingWidget? ratingWidget, int itemCount = 5, Axis direction = Axis.horizontal, bool allowHalfRating = true, EdgeInsetsGeometry itemPadding = EdgeInsets.zero, double itemSize = 24, Color? filledColor, Color? emptyColor})
-
Creates a UIRatingBarIndicator with a fixed
ratingWidgetfor every item.const - UIRatingBarIndicator.builder({Key? key, required double rating, required UIRatingItemBuilder? itemBuilder, int itemCount = 5, Axis direction = Axis.horizontal, bool allowHalfRating = true, EdgeInsetsGeometry itemPadding = EdgeInsets.zero, double itemSize = 24, Color? filledColor, Color? emptyColor})
-
Creates a UIRatingBarIndicator with a per-index
itemBuilder.const
Properties
- allowHalfRating → bool
-
Whether half-step display is enabled.
final
- direction → Axis
-
Layout direction of the rating items.
final
- emptyColor → Color?
-
Color for empty stars when using the built-in star widget.
final
- filledColor → Color?
-
Color for filled stars when using the built-in star widget.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemBuilder → UIRatingItemBuilder?
-
Builds each rating item; supports per-index customization.
final
- itemCount → int
-
Number of rating items.
final
- itemPadding → EdgeInsetsGeometry
-
Padding around each item.
final
- itemSize → double
-
Default icon size when using the built-in star widget.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- rating → double
-
Rating value to display.
final
- ratingWidget → UIRatingWidget?
-
Fixed full/half/empty widgets for every item.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
copyWith(
{Key? key, double? rating, UIRatingWidget? ratingWidget, UIRatingItemBuilder? itemBuilder, int? itemCount, Axis? direction, bool? allowHalfRating, EdgeInsetsGeometry? itemPadding, double? itemSize, Color? filledColor, Color? emptyColor}) → UIRatingBarIndicator -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited