UIRatingWidget class
Full, half, and empty widgets used by the rating bar widgets.
- Annotations
Constructors
- UIRatingWidget({required Widget full, required Widget half, required Widget empty})
-
Creates a UIRatingWidget.
const
Properties
- empty → Widget
-
Widget shown when the item is unrated.
final
- full → Widget
-
Widget shown when the item is fully rated.
final
- half → Widget
-
Widget shown when the item is half rated.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited