UISplitButtonMenuItem class
One action in the menu opened by UISplitButton.
Constructors
- UISplitButtonMenuItem({required String label, IconData? icon, VoidCallback? onTap, bool enabled = true, bool destructive = false})
-
const
Properties
- destructive → bool
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
final
- label → String
-
final
- onTap → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toContextMenuItem(
) → UIContextMenuItem -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited