UIThemeColors class abstract
Semantic color tokens used to build a UIAppTheme.
Host apps can pass a custom implementation to buildUIKitTheme, or use the built-in UIThemePalette.light / UIThemePalette.dark presets.
- Implementers
Constructors
Properties
- accent → Color
-
Primary accent/brand color.
no setter
- accentSecondary → Color
-
Secondary accent color.
no setter
- card → Color
-
Background color for Card and related components.
no setter
- chipBackground → Color
-
Background color for Chip components.
no setter
- chipBorder → Color
-
Border color for Chip components.
no setter
- chipLabel → Color
-
Text/Label color for Chip components.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaffold → Color
-
Background color for Scaffold.
no setter
- sectionBorder → Color
-
Border color for section dividers.
no setter
- surface → Color
-
General surface color.
no setter
- textMuted → Color
-
Muted text color for less important information.
no setter
- textPrimary → Color
-
Primary text color.
no setter
- textSecondary → Color
-
Secondary text color.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited